@@ -32,18 +32,16 @@ G_BEGIN_DECLS
 #define ASB_TYPE_PACKAGE (asb_package_get_type ())
 G_DECLARE_DERIVABLE_TYPE (AsbPackage, asb_package, ASB, PACKAGE, GObject)
 
-typedef enum {
-	ASB_PACKAGE_ENSURE_NONE		= 0,
-	ASB_PACKAGE_ENSURE_NEVRA	= 1,
-	ASB_PACKAGE_ENSURE_FILES	= 2,
-	ASB_PACKAGE_ENSURE_RELEASES	= 4,
-	ASB_PACKAGE_ENSURE_DEPS		= 8,
-	ASB_PACKAGE_ENSURE_LICENSE	= 16,
-	ASB_PACKAGE_ENSURE_URL		= 32,
-	ASB_PACKAGE_ENSURE_SOURCE	= 64,
-	ASB_PACKAGE_ENSURE_VCS		= 128,
-	ASB_PACKAGE_ENSURE_LAST
-} AsbPackageEnsureFlags;
+#define ASB_PACKAGE_ENSURE_NONE		(0u)
+#define ASB_PACKAGE_ENSURE_NEVRA	(1u << 0)
+#define ASB_PACKAGE_ENSURE_FILES	(1u << 1)
+#define ASB_PACKAGE_ENSURE_RELEASES	(1u << 2)
+#define ASB_PACKAGE_ENSURE_DEPS		(1u << 3)
+#define ASB_PACKAGE_ENSURE_LICENSE	(1u << 4)
+#define ASB_PACKAGE_ENSURE_URL		(1u << 5)
+#define ASB_PACKAGE_ENSURE_SOURCE	(1u << 6)
+#define ASB_PACKAGE_ENSURE_VCS		(1u << 7)
+typedef guint64 AsbPackageEnsureFlags;
 
 struct _AsbPackageClass
 {
